aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--hm/soispha/conf/nvim/options/default.nix2
1 files changed, 1 insertions, 1 deletions
diff --git a/hm/soispha/conf/nvim/options/default.nix b/hm/soispha/conf/nvim/options/default.nix
index 879a5cd1..67b86dfc 100644
--- a/hm/soispha/conf/nvim/options/default.nix
+++ b/hm/soispha/conf/nvim/options/default.nix
@@ -84,7 +84,7 @@
virtualedit = "block"; # allow the cursor to move beyond actual character in visual block mode
- textwidth = 120; # automatically hard wrap at 120 columns by default
+ textwidth = 90; # automatically hard wrap at 90 columns by default
foldmethod = "marker"; # use markers to specify folds